@@ -1,4 +1,5 @@
 """Implementation of Basic KNX 2-Byte/octet values."""
+from typing import Optional, Tuple
 
 from xknx.exceptions import ConversionError
 
@@ -17,20 +18,20 @@ class DPT2ByteUnsigned(DPTBase):
     value_min = 0
     value_max = 65535
     dpt_main_number = 7
-    dpt_sub_number = None
+    dpt_sub_number: Optional[int] = None
     value_type = "2byte_unsigned"
     unit = ""
     resolution = 1
     payload_length = 2
 
     @classmethod
-    def from_knx(cls, raw):
+    def from_knx(cls, raw: Tuple[int, ...]) -> int:
         """Parse/deserialize from KNX/IP raw data."""
         cls.test_bytesarray(raw)
         return (raw[0] * 256) + raw[1]
 
     @classmethod
-    def to_knx(cls, value):
+    def to_knx(cls, value: int) -> Tuple[int, int]:
         """Serialize to KNX/IP raw data."""
         try:
             knx_value = int(value)
@@ -41,7 +42,7 @@ class DPT2ByteUnsigned(DPTBase):
             raise ConversionError("Could not serialize %s" % cls.__name__, value=value)
 
     @classmethod
-    def _test_boundaries(cls, value):
+    def _test_boundaries(cls, value: int) -> bool:
         """Test if value is within defined range for this object."""
         return cls.value_min <= value <= cls.value_max
 
